use strict;
use warnings;

package FailSchema;

use base 'DBIx::Class::Schema';

1;
